==> groovy-all-2.2.1-sources.jar: org/codehaus/groovy/control/io/InputStreamReaderSource.java <==
/*
 * Copyright 2003-2007 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.codehaus.groovy.control.io;

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;

import org.codehaus.groovy.control.CompilerConfiguration;

/**
 * A ReaderSource for source strings.
 *
 * @author <a href="mailto:cpoirier@dreaming.org">Chris Poirier</a>
 * @version $Id$
 */
public class InputStreamReaderSource extends AbstractReaderSource {
    private InputStream stream;  // The InputStream from which we produce a Reader.

    /**
     * Creates the ReaderSource from a File descriptor.
     *
     * @param stream        stream containing source
     * @param configuration configuration for compiling source
     */
    public InputStreamReaderSource(InputStream stream, CompilerConfiguration configuration) {
        super(configuration);
        this.stream = stream;
    }

    /**
     * Returns a new Reader on the underlying source object.
     */
    public Reader getReader() throws IOException {
        if (stream != null) {
            Reader reader = new InputStreamReader(stream, configuration.getSourceEncoding());
            stream = null;
            return reader;
        }
        return null;
    }

    /**
     * Returns true if the source can be restarted (ie. if getReader()
     * will return non-null on subsequent calls.
     */
    public boolean canReopenSource() {
        return false;
    }
}

==> groovy-all-2.4.1-sources.jar: org/codehaus/groovy/control/io/InputStreamReaderSource.java <==
/*
 * Copyright 2003-2007 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.codehaus.groovy.control.io;

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.net.URI;

import org.codehaus.groovy.control.CompilerConfiguration;

/**
 * A ReaderSource for source strings.
 *
 * @author <a href="mailto:cpoirier@dreaming.org">Chris Poirier</a>
 * @version $Id$
 */
public class InputStreamReaderSource extends AbstractReaderSource {
    private InputStream stream;  // The InputStream from which we produce a Reader.

    /**
     * Creates the ReaderSource from a File descriptor.
     *
     * @param stream        stream containing source
     * @param configuration configuration for compiling source
     */
    public InputStreamReaderSource(InputStream stream, CompilerConfiguration configuration) {
        super(configuration);
        this.stream = stream;
    }

    /**
     * Returns a new Reader on the underlying source object.
     */
    public Reader getReader() throws IOException {
        if (stream != null) {
            Reader reader = new InputStreamReader(stream, configuration.getSourceEncoding());
            stream = null;
            return reader;
        }
        return null;
    }

    /**
     * Returns true if the source can be restarted (ie. if getReader()
     * will return non-null on subsequent calls.
     */
    public boolean canReopenSource() {
        return false;
    }

    /**
     * TODO: Should return the URI for this source, but we can't know what it is here.
     *
     * @return null
     */
    public URI getURI() {
        return null;
    }
}
